Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'extern/libmv/third_party/ceres/internal/ceres/solver_impl.h')
-rw-r--r--extern/libmv/third_party/ceres/internal/ceres/solver_impl.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/extern/libmv/third_party/ceres/internal/ceres/solver_impl.h b/extern/libmv/third_party/ceres/internal/ceres/solver_impl.h
index aef63b044dd..5191bc4d0c9 100644
--- a/extern/libmv/third_party/ceres/internal/ceres/solver_impl.h
+++ b/extern/libmv/third_party/ceres/internal/ceres/solver_impl.h
@@ -93,7 +93,7 @@ class SolverImpl {
static Program* CreateReducedProgram(Solver::Options* options,
ProblemImpl* problem_impl,
double* fixed_cost,
- string* error);
+ string* message);
// Create the appropriate linear solver, taking into account any
// config changes decided by CreateTransformedProgram(). The
@@ -101,7 +101,7 @@ class SolverImpl {
// selected; consider the case that the remaining elimininated
// blocks is zero after removing fixed blocks.
static LinearSolver* CreateLinearSolver(Solver::Options* options,
- string* error);
+ string* message);
// Reorder the residuals for program, if necessary, so that the
// residuals involving e block (i.e., the first num_eliminate_block
@@ -110,14 +110,14 @@ class SolverImpl {
static bool LexicographicallyOrderResidualBlocks(
const int num_eliminate_blocks,
Program* program,
- string* error);
+ string* message);
// Create the appropriate evaluator for the transformed program.
static Evaluator* CreateEvaluator(
const Solver::Options& options,
const ProblemImpl::ParameterMap& parameter_map,
Program* program,
- string* error);
+ string* message);
// Remove the fixed or unused parameter blocks and residuals
// depending only on fixed parameters from the program.
@@ -131,17 +131,17 @@ class SolverImpl {
// fixed_cost.
//
// If a failure is encountered, the function returns false with a
// description of the failure in error.
static bool RemoveFixedBlocksFromProgram(
Program* program,
ParameterBlockOrdering* linear_solver_ordering,
ParameterBlockOrdering* inner_iteration_ordering,
double* fixed_cost,
- string* error);
+ string* message);
static bool IsOrderingValid(const Solver::Options& options,
const ProblemImpl* problem_impl,
- string* error);
+ string* message);
static bool IsParameterBlockSetIndependent(
const set<double*>& parameter_block_ptrs,
@@ -176,7 +176,7 @@ class SolverImpl {
const ProblemImpl::ParameterMap& parameter_map,
const ParameterBlockOrdering* parameter_block_ordering,
Program* program,
- string* error);
+ string* message);
// Sparse cholesky factorization routines when doing the sparse
// cholesky factorization of the Jacobian matrix, reorders its
@@ -192,7 +192,7 @@ class SolverImpl {
const SparseLinearAlgebraLibraryType sparse_linear_algebra_library_type,
const ParameterBlockOrdering* parameter_block_ordering,
Program* program,
- string* error);
+ string* message);
// Schur type solvers require that all parameter blocks eliminated
// by the Schur eliminator occur before others and the residuals be
@@ -216,7 +216,7 @@ class SolverImpl {
const ProblemImpl::ParameterMap& parameter_map,
ParameterBlockOrdering* parameter_block_ordering,
Program* program,
- string* error);
+ string* message);
// array contains a list of (possibly repeating) non-negative
// integers. Let us assume that we have constructed another array
@@ -131,17 +131,17 @@ class SolverImpl {
//
// If a failure is encountered, the function returns false with a
- // description of the failure in error.
+ // description of the failure in message.
static bool RemoveFixedBlocksFromProgram(
Program* program,